@@ -46,6 +46,21 @@ WlEglSurface *wlEglCreateSurfaceExport(EGLDisplay dpy,
                                        struct wl_surface *native_surface,
                                        int fifo_length);
 
+WL_EXPORT
+WlEglSurface *wlEglCreateSurfaceExport2(EGLDisplay dpy,
+                                        int width,
+                                        int height,
+                                        struct wl_surface *native_surface,
+                                        int fifo_length,
+                                        int (*present_update_callback)(void*, uint64_t, int),
+                                        const EGLAttrib *attribs);
+
+WL_EXPORT
+int wlEglWaitAllPresentationFeedbacksExport(WlEglSurface *surface);
+
+WL_EXPORT
+int wlEglProcessPresentationFeedbacksExport(WlEglSurface *surface);
+
 #ifdef __cplusplus
 }
 #endif
